Enum BarycentricError

#[non_exhaustive]
pub enum BarycentricError { NonFinite, Degenerate { thickness: Scalar, }, TooFewVertices { count: usize, }, ShortEdge { index: usize, }, SelfIntersecting { first: usize, second: usize, }, Undefined, }
Why coordinates could not be computed.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NonFinite

A corner or the query point is not finite.



Degenerate

The triangle, tetrahedron or polygon is thinner than the linear tolerance: its least altitude (for a polygon, twice its area over its perimeter) is thickness.

Fields

thickness: Scalar

The shape’s thickness, in length units.



TooFewVertices

A polygon has fewer than three vertices.

Fields

count: usize

The number of vertices given.



ShortEdge

Polygon edge index, from vertex index to the next, is no longer than the linear tolerance.

Fields

index: usize

The edge’s index.



SelfIntersecting

Polygon edges first and second cross, touch or fold back onto each other within the linear tolerance, so the polygon is not simple.

Fields

first: usize

The lower edge index.

second: usize

The higher edge index.



Undefined

The mean-value weights cancel at this point, which can happen only outside a non-convex polygon: the coordinates are undefined there.